@@ -36,26 +36,25 @@ class RowModel(base.APIModel):
     #   just make the ID a string repr of the row.  No use case
     #   for it as of now since all rows are read-only.
     # def get_item(self, id_, context=None):
-    #     """Retrieve item with id id_ from model.
+    #     """Retrieve item with id id\_ from model.
 
     #     Args:
     #         id_: The ID of the item to retrieve
     #         context: Key-values providing frame of reference of request
 
     #     Returns:
-    #          The matching item or None if item with id_ does not exist.
+    #          The matching item or None if item with id\_ does not exist.
     #     """
 
     # Note(thread-safety): blocking function
     def get_items(self, params, context=None):
         """Get items in model.
 
-        Args:
-            params: A dict-like object containing parameters
+        :param: params: A dict-like object containing parameters
                     from the request query string and body.
-            context: Key-values providing frame of reference of request
+        :param: context: Key-values providing frame of reference of request
 
-        Returns: A dict containing at least a 'results' key whose value is
+        :returns: A dict containing at least a 'results' key whose value is
                  a list of items in the model.  Additional keys set in the
                  dict will also be rendered for the user.
         """
@@ -78,7 +77,7 @@ class RowModel(base.APIModel):
         try:
             args = {'table_id': table_id, 'source_id': source_id,
                     'trace': gen_trace}
-            if caller is base.ENGINE_SERVICE:
+            if caller is base.ENGINE_SERVICE_ID:
                 # allow extra time for row policy engine query
                 # Note(thread-safety): blocking call
                 result = self.invoke_rpc(
@@ -93,7 +92,7 @@ class RowModel(base.APIModel):
             LOG.exception(m)
             raise webservice.DataModelException.create(e)
 
-        if gen_trace and caller is base.ENGINE_SERVICE:
+        if gen_trace and caller is base.ENGINE_SERVICE_ID:
             # DSE2 returns lists instead of tuples, so correct that.
             results = [{'data': tuple(x['data'])} for x in result[0]]
             return {'results': results,
@@ -103,21 +102,19 @@ class RowModel(base.APIModel):
             return {'results': result}
 
     # Note(thread-safety): blocking function
-    def update_items(self, items, params, context=None):
-        """Updates all data in a table.
+    def replace_items(self, items, params, context=None):
+        """Replaces all data in a table.
 
-        Args:
-            id_: A table id for updating all row
-            items: A data for new rows
-            params: A dict-like object containing parameters from
+        :param: id\_: A table id for replacing all row
+        :param: items: A data for new rows
+        :param: params: A dict-like object containing parameters from
                     request query
-            context: Key-values providing frame of reference of request
-        Returns: None
-        Raises:
-            KeyError: table id doesn't exist
-            DataModelException: any error occurs during replacing rows.
+        :param: context: Key-values providing frame of reference of request
+        :returns: None
+        :raises KeyError: table id doesn't exist
+        :raises DataModelException: any error occurs during replacing rows.
         """
-        LOG.info("update_items(context=%s)", context)
+        LOG.info("replace_items(context=%s)", context)
         # Note(thread-safety): blocking call
         caller, source_id = api_utils.get_id_from_context(context)
         # FIXME(threod-safety): in DSE2, the returned caller can be a
@@ -132,14 +129,14 @@ class RowModel(base.APIModel):
             args = {'table_id': table_id, 'source_id': source_id,
                     'objs': items}
             # Note(thread-safety): blocking call
-            self.invoke_rpc(caller, 'update_entire_data', args)
+            self.invoke_rpc(caller, 'replace_entire_table_data', args)
         except exception.CongressException as e:
             LOG.exception("Error occurred while processing updating rows "
                           "for source_id '%s' and table_id '%s'",
                           source_id, table_id)
             raise webservice.DataModelException.create(e)
-        LOG.info("finish update_items(context=%s)", context)
-        LOG.debug("updated table %s with row items: %s",
+        LOG.info("finish replace_items(context=%s)", context)
+        LOG.debug("replaced table %s with row items: %s",
                   table_id, str(items))
 
     # TODO(thinrichs): It makes sense to sometimes allow users to create
@@ -165,7 +162,7 @@ class RowModel(base.APIModel):
     #   add the ability to update a row.  (Or maybe not and implement
     #   via add+delete.)
     # def update_item(self, id_, item, context=None):
-    #     """Update item with id_ with new data.
+    #     """Update item with id\_ with new data.
 
     #     Args:
     #         id_: The ID of the item to be updated
@@ -176,7 +173,7 @@ class RowModel(base.APIModel):
     #          The updated item.
 
     #     Raises:
-    #         KeyError: Item with specified id_ not present.
+    #         KeyError: Item with specified id\_ not present.
     #     """
     #     # currently a noop since the owner_id cannot be changed
     #     if id_ not in self.items:
@@ -196,5 +193,5 @@ class RowModel(base.APIModel):
         #      The removed item.
 
         # Raises:
-        #     KeyError: Item with specified id_ not present.
+        #     KeyError: Item with specified id\_ not present.
         # """
